#include <iostream>
#include <vector>
#include <list>
#include <algorithm>

using namespace std;

bool check_bno(int a, int b, int c)
{
    for(int i = 0; i < c; i++)
    {
        if(a % 3 == b % 3 && a % 3 != 1)
            return false;
        a /= 3;
        b /= 3;
    }
    return true;
}

struct edge
{
    int to;
    int* pos;
    int* neg;
};

int all_posnegs[10000000];
int* posneg_ptr = all_posnegs;

inline void create_edge(vector<edge>* graph, int from, int to, int cap)
{
    int* posneg = posneg_ptr;
    posneg_ptr += 2;
    posneg[0] = 0;
    posneg[1] = cap;
    graph[from].push_back({to, posneg, posneg + 1});
    graph[to].push_back({from, posneg + 1, posneg});
}

int enlarge(vector<edge>* graph, long double* dist, vector<bool>& used, int i, int f, int limit = (1 << 31) - 1)
{
    if(limit == 0 || used[i])
        return 0;
    if(i == f)
        return limit;
    used[i] = true;
    int ans = 0;
    for(edge& j : graph[i])
    {
        if(dist[j.to] != dist[i] + 1)
            continue;
        int cur = enlarge(graph, dist, used, j.to, f, min(limit, *j.neg));
        if(cur)
        {
            j.pos[0] += cur;
            j.neg[0] -= cur;
            ans += cur;
            limit -= cur;
        }
    }
    return ans;
}

int main()
{
    int n, k;
    cin >> n >> k;
    vector<pair<vector<int>, int> > data(n);
    for(int i = 0; i < n; i++)
    {
        data[i].first.resize(k);
        for(int j = 0; j < k; j++)
            cin >> data[i].first[j];
        data[i].second = i;
    }
    int bvalues[k];
    for(int i = 0; i < k; i++)
    {
        sort(data.begin(), data.end(), [&](const pair<vector<int>, int>& a, const pair<vector<int>, int>& b)
        {
            return a.first[i] < b.first[i];
        });
        bvalues[i] = data[n / 2].first[i] + data[n / 2 - 1].first[i];
    }
    sort(data.begin(), data.end(), [](const pair<vector<int>, int>& a, const pair<vector<int>, int>& b)
    {
        return a.second < b.second;
    });
    int types[n][k];
    for(int i = 0; i < n; i++)
        for(int j = 0; j < k; j++)
        {
            if(data[i].first[j] * 2 < bvalues[j])
                types[i][j] = 0;
            else if(data[i].first[j] * 2 > bvalues[j])
                types[i][j] = 2;
            else
                types[i][j] = 1;
        }
    int pow3[8] = {1, 3, 9, 27, 81, 243, 729, 2187};
    int m = pow3[k];
    vector<int> buckets[m];
    for(int i = 0; i < n; i++)
    {
        int bno = 0;
        for(int j = k - 1; j >= 0; j--)
            bno = 3 * bno + types[i][j];
        buckets[bno].push_back(i);
    }
    vector<edge> edges[m + 2];
    for(int i = 0; i < m; i += 3)
        if(!buckets[i].empty())
            for(int j = 0; j < m; j++)
                if(!buckets[j].empty() && check_bno(i, j, k))
                    create_edge(edges, i, j, 1000000000);
    for(int i = 0; i < m; i += 3)
        if(!buckets[i].empty())
            create_edge(edges, m, i, buckets[i].size());
    for(int i = 2; i < m; i += 3)
        if(!buckets[i].empty())
            create_edge(edges, i, m + 1, buckets[i].size());
    while(true)
    {
        long double dist[m + 2];
        for(int i = 0; i < m + 2; i++)
            dist[i] = 1. / 0;
        dist[m] = 0;
        vector<int> queue1, queue2;
        queue1.push_back(m);
        while(!queue1.empty())
        {
            while(!queue1.empty())
            {
                int i = queue1.back();
                queue1.pop_back();
                for(edge& e : edges[i])
                    if(dist[e.to] * 0 && e.neg[0] > 0)
                    {
                        dist[e.to] = dist[i] + 1;
                        queue2.push_back(e.to);
                    }
            }
            swap(queue1, queue2);
        }
        vector<bool> used(m + 2);
        if(!enlarge(edges, dist, used, m, m + 1))
            break;
    }
    int ans = 0;
    for(edge& i : edges[m])
        ans += *i.pos;
    if(ans * 2 != n)
    {
        cout << "NO\n";
        return 0;
    }
    cout << "YES\n";
    for(int i = 0; i < m; i += 3)
        for(edge& e : edges[i])
            if(e.to < m)
                for(int j = 0; j < *e.pos; j++)
                {
                    cout << buckets[i].back() + 1 << ' ' << buckets[e.to].back() + 1 << endl;
                    buckets[i].pop_back();
                    buckets[e.to].pop_back();
                }
    return 0;
}
