#include <iostream>
#include <algorithm>
#include <cmath>
#include <vector>
#include <set>
#include <map>
using namespace std;

#define int long long

struct node {
	int val, prior, sz, mx;
	node *l, *r;
	node(int v)
	{
		val = v;
		mx = v;
		sz = 1;
		prior = (rand() << 16) | rand();
		l = nullptr;
		r = nullptr;
	}
};

int sz(node * tree)
{
	if (tree == nullptr)
	{
		return 0;
	}
	return tree->sz;
}

int mx(node * tree)
{
	if (tree == nullptr)
		return -1e9;
	return tree->mx;
}

void upd(node * tree)
{
	if (tree == nullptr)
		return;
	tree->sz = 1 + sz(tree->l) + sz(tree->r);
	tree->mx = max(tree->val, max(mx(tree->l), mx(tree->r)));
}

node * merge(node * tree_l, node * tree_r)
{
	if (tree_l == nullptr)
		return tree_r;
	if (tree_r == nullptr)
		return tree_l;
	if (tree_l->prior < tree_r->prior)
	{
		tree_l->r = merge(tree_l->r, tree_r);
		upd(tree_l);
		return tree_l;
	}
	else
	{
		tree_r->l = merge(tree_l, tree_r->l);
		upd(tree_r);
		return tree_r;
	}
}

pair <node *, node *> split(node * tree, int size)
{
	if (tree == nullptr)
		return { nullptr, nullptr };
	if (sz(tree->l) >= size)
	{
		auto p = split(tree->l, size);
		tree->l = p.second;
		upd(tree);
		return { p.first, tree };
	}
	else
	{
		auto p = split(tree->r, size);
		tree->r = p.first;
		upd(tree);
		return { tree, p.second };
	}
}

node * insert(node * tree, node * x, int pos)
{
	if (tree == nullptr)
		return x;
	auto p = split(tree, pos);
	auto i = merge(p.first, x);
	auto j = merge(i, p.second);
	upd(j);
	return j;
}

node * del(node * tree)
{
	if (tree == nullptr)
		return nullptr;
	if (tree->l != nullptr)
	{
		tree->l = del(tree->l);
		upd(tree);
		return tree;
	}
	if (tree->l == nullptr)
		if (tree->r != nullptr)
			return tree->r;
		else
			return nullptr;
}

node * left(node * tree)
{
	if (tree == nullptr)
		return nullptr;
	if (tree->l != nullptr)
		return left(tree->l);
	return tree;
}

const int MAXN = 3 * 1e5 + 10;
int a[MAXN], b[MAXN];
int n, m;
bool flag_g1 = true, flag_g2 = true;

set <int> help[MAXN];
node * tree;
map <int, int> help2;
void read()
{
	cin >> n >> m;
	if (n != m)
	{
		flag_g1 = false;
		flag_g2 = false;
	}
	for (int i = 0; i < m; i++)
	{
		cin >> a[i];
		help[a[i]].insert(i);
	}
	for (int i = 0; i < n; i++)
	{
		cin >> b[i];
		help2[b[i]] = i;
		if (n == m)
		{
			if (a[i] != b[i])
				flag_g1 = false;
			if (b[i] != a[n - 1 - i])
				flag_g2 = false;
		}
		tree = insert(tree, new node(b[i]), i);
	}
}
vector <int> ans;

void run_g1()
{
	ans.assign(n, n);
}

void run_g2()
{
	ans.assign(2 * n - 1, 0);
	for (int i = 0; i < n - 1; i++)
	{
		ans[i] = n - i;
	}
	for (int i = 0; i < n; i++)
	{
		ans[i + n - 1] = n;
	}
}

int T[MAXN * 4];
int mod[MAXN * 4];
void build(int v, int l, int r)
{
	mod[v] = 0;
	if (l == r - 1)
	{
		T[v] = help2[a[l]];
		return;
	}
	int m = (l + r) / 2;
	build(v * 2, l, m);
	build(v * 2 + 1, m, r);
	T[v] = max(T[v * 2], T[v * 2 + 1]);
}

void push(int v)
{
	mod[v * 2] += mod[v];
	mod[v * 2 + 1] += mod[v];
	mod[v] = 0;
}

int get_val(int v)
{
	return mod[v] + T[v];
}

void update(int v, int tl, int tr, int l, int r, int val)
{
	if (tl >= r || tr <= l)
		return;
	if (tl >= l && tr <= r)
	{
		mod[v] += val;
		return;
	}
	push(v);
	int tm = (tl + tr) / 2;
	update(v * 2, tl, tm, l, r, val);
	update(v * 2 + 1, tm, tr, l, r, val);
	T[v] = max(get_val(v * 2), get_val(v * 2 + 1));
}

int get(int v, int tl, int tr, int l, int r)
{
	if (tl >= r || tr <= l)
		return -1e9;
	if (tl >= l && tr <= r)
		return get_val(v);
	push(v);
	int tm = (tl + tr) / 2;
	return max(get(v * 2, tl, tm, l, r), get(v * 2 + 1, tm, tr, l, r));
}

void write(node * tree)
{
	if (tree == nullptr)
		return;
	write(tree->l);
	cout << tree->val << " ";
	write(tree->r);
}

void run()
{
	build(1, 0, n);
	int mxN = n;
	for (int test = 0; test < m; test++)
	{
		while (true)
		{
			int x = a[test];
			auto L = left(tree);
			tree = del(tree);
			//write(tree);
			//cout << endl;
			if (x == L->val)
			{
				if (help[x].size() > 1)
				{
					help[x].erase(help[x].begin());
					int pos_x = *help[x].begin();
					int pos = get(1, 0, n, test, pos_x);
					tree = insert(tree, new node(x), pos);
					//		write(tree);
					//		cout << endl;
					update(1, 0, n, test, pos, -1);
					for (auto i : help[x])
					{
						int plus = pos - get(1, 0, n, i, i + 1);
						update(1, 0, n, i, i + 1, plus);
					}
					ans.push_back(pos + 1);
				}
				else
				{
					if (help[x].size() > 0)
						help[x].erase(help[x].begin());
					tree = insert(tree, new node(x), mxN - 1);
					//		write(tree);
					//		cout << endl;
					update(1, 0, n, test, n, -1);
					ans.push_back(mxN);

				}
				break;
			}
			else
			{
				x = L->val;
				if (help[x].size() > 0)
				{
					int pos_x = *help[x].begin();
					int pos = get(1, 0, n, test, pos_x);
					tree = insert(tree, new node(x), pos);
					//		write(tree);
					//		cout << endl;
					update(1, 0, n, test, pos, -1);
					for (auto i : help[x])
					{
						int plus = pos - get(1, 0, n, i, i + 1);
						update(1, 0, n, i, i + 1, pos);
					}
					ans.push_back(pos + 1);
				}
				else
				{
					tree = insert(tree, new node(x), mxN - 1);
					//		write(tree);
							//cout << endl;
					update(1, 0, n, test, n, -1);
					ans.push_back(mxN);

				}
			}
		}
	}
}
void write()
{
	cout << ans.size() << endl;
	for (auto i : ans)
		cout << i << " ";
}

signed main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	read();
	if (flag_g1)
		run_g1();
	else if (flag_g2)
		run_g2();
	else
		run();

	write();
	return 0;
}