#include <stdio.h>
#include <vector>
#include <algorithm>
#include <queue>
#include <utility>

namespace lol {
	int n, k, *bo, **arr, *pa, *used, color = 1;

	bool check(int u, int v) {
		for (int i = 0; i < k; i++) {
			if ((arr[u][i] < bo[i] && arr[v][i] < bo[i]) || (arr[u][i] > bo[i] && arr[v][i] > bo[i])) {
				return false;
			}
		}
		return true;
	}

	bool try_kuhn(int v) {
		used[v] = color;
		for (int u = 0; u < n; u++) {
			if (check(u, v) && (pa[u] == -1 || (used[pa[u]] != color && try_kuhn(pa[u])))) {
				pa[u] = v;
				return true;
			}
		}
		return false;
	}

	void main(int nn, int kk) {
		n = nn;
		k = kk;
		arr = new int*[n];
		used = new int[n]();
		pa = new int[n];
		bo = new int[k];
		for (int i = 0; i < n; i++) {
			pa[i] = -1;
			arr[i] = new int[k];
			for (int j = 0; j < k; j++) {
				scanf("%d", &arr[i][j]);
			}
		}
		for (int i = 0; i < k; i++) {
			int a[n];
			for (int j = 0; j < n; j++) {
				a[j] = arr[j][i];
			}
			std::nth_element(a, a + n / 2, a + n);
			bo[i] = a[n / 2];
		}
		for (int i = 0; i < n; i++) {
			if (arr[i][0] < bo[0]) {
				if (!try_kuhn(i)) {
					printf("NO");
					return;
				}
				color++;
			}
		}
		printf("YES\n");
		for (int i = 0; i < n; i++) {
			if (pa[i] != -1) {
				printf("%d %d\n", i + 1, pa[i] + 1);
			}
		}
	}
}

const int TYPES = 729, INF = 1e9;
int k, in[2][TYPES];

bool check(int u, int v) {
	for (int i = 0; i < k - 1; i++) {
		if (u % 3 != 1 && v % 3 != 1 && u % 3 == v % 3) {
			return false;
		}
		u /= 3;
		v /= 3;
	}
	return true;
}

struct edge {
	int c, f, v;
	edge(){}
	edge(int cc, int ff, int vv): c(cc), f(ff), v(vv) {}
};

std::vector<int> graph[2 * TYPES + 2];
std::vector<edge> e;

void add(int u, int v, int c) {
	int nu = (int)e.size() / 2;
	e.push_back(edge(c, 0, v));
	e.push_back(edge(0, 0, u));
	graph[u].push_back(2 * nu);
	graph[v].push_back(2 * nu + 1);
}

int d[2 * TYPES + 2], mi, ind[2 * TYPES + 2];
bool used[2 * TYPES + 2];

void bfs(int m) {
	for (int i = 0; i < 2 * TYPES + 2; i++) {
		d[i] = INF;
		used[i] = false;
		ind[i] = 0;
	}
	used[0] = true;
	std::queue<std::pair<int, int> > q;
	q.push(std::make_pair(0, 0));
	while (!q.empty()) {
		std::pair<int, int> p = q.front();
		q.pop();
		d[p.first] = p.second;
		for (int i = 0; i < (int)graph[p.first].size(); i++) {
			int en = graph[p.first][i];
			if (e[en].f + m <= e[en].c && !used[e[en].v]) {
				used[e[en].v] = true;
				q.push(std::make_pair(e[en].v, p.second + 1));
			}
		}
	}
}

bool dfs(int v, int fi, int m, int prm) {
	if (v == fi) {
		mi = prm;
		return true;
	}
	for (; ind[v] < (int)graph[v].size(); ind[v]++) {
		int en = graph[v][ind[v]];
		int u = e[en].v;
		if (e[en].f + m <= e[en].c && d[u] == d[v] + 1 && dfs(u, fi, m, std::min(prm, e[en].c - e[en].f))) {
			e[en].f += mi;
			e[en ^ 1].f -= mi;
			return true;
		}
	}
	return false;
}

void getflow(int cap) {
	while (cap > 0) {
		bfs(cap);
		while (dfs(0, 2 * TYPES + 1, cap, INF)){}
		cap /= 2;
	}
}

int main() {
	e.reserve(1065798);
	int n;
	scanf("%d%d", &n, &k);
	if (n <= 400) {
		lol::main(n, k);
		return 0;
	}
	int arr[n][k];
	int bo[k], bo1[k];
	for (int i = 0; i < n; i++) {
		for (int j = 0; j < k; j++) {
			scanf("%d", &arr[i][j]);
		}
	}
	for (int i = 0; i < k; i++) {
		int a[n];
		for (int j = 0; j < n; j++) {
			a[j] = arr[j][i];
		}
		std::nth_element(a, a + n / 2, a + n);
		bo[i] = a[n / 2];
		std::nth_element(a, a + n / 2 - 1, a + n);
		bo1[i] = a[n / 2 - 1];
	}
	std::vector<int> typ[2][TYPES];
	for (int i = 0; i < n; i++) {
		int ty = 0;
		for (int j = 1; j < k; j++) {
			int di = 0;
			if (arr[i][j] >= bo[j]) {
				di = 2;
			}
			if (arr[i][j] == bo[j] && bo[j] == bo1[j]) {
				di = 1;
			}
			ty *= 3;
			ty += di;
		}
		if (arr[i][0] < bo[0]) {
			typ[0][ty].push_back(i);
		} else {
			typ[1][ty].push_back(i);
		}
	}
	for (int i = 0; i < TYPES; i++) {
		add(0, i + 1, (int)typ[0][i].size());
		add(TYPES + i + 1, 2 * TYPES + 1, (int)typ[1][i].size());
	}
	for (int i = 0; i < TYPES; i++) {
		for (int j = 0; j < TYPES; j++) {
			if (check(i, j)) {
				add(i + 1, TYPES + j + 1, INF);
			}
		}
	}
	getflow(n / 2);
	int flow = 0;
	for (int en : graph[0]) {
		if (en % 2 == 0) {
			flow += e[en].f;
		}
	}
	if (flow != n / 2) {
		printf("NO");
		return 0;
	}
	printf("YES\n");
	for (int i = 0; i < TYPES; i++) {
		for (int j : graph[i + 1]) {
			if (j % 2 == 0) {
				for (int ii = 0; ii < e[j].f; ii++) {
					printf("%d %d\n", typ[0][i][in[0][i]++] + 1, typ[1][e[j].v - TYPES - 1][in[1][e[j].v - TYPES - 1]++] + 1);
				}
			}
		}
	}
	return 0;
}
