#include <iostream>
#include <cmath>
#include <set>
#include <vector>
#include <algorithm>

using namespace std;

const long long BIT_SZ = 100;
const long long SZ = 3e5 + 10;
const long long MOD = 1e9 + 7;

long long n, m, k;

long long fact[SZ];
long long obr[SZ];

long long get_step(long long a, long long b)
{
    long long dop = 1;
    while (b > 1) {
        if (b & 1)
            dop *= a;
        a *= a;
        b >>= 1;
        a %= MOD;
        dop %= MOD;
    }
    return a * dop % MOD;
}

void build_fact()
{
    fact[0] = 1;
    for (long long i = 1; i <= 3e5; i++)
        fact[i] = fact[i - 1] * i % MOD;
    for (long long i = 0; i <= 3e5; i++)
        obr[i] = get_step(fact[i], MOD - 2);
}

long long get_C(long long n, long long k)
{
    if (k > n)
        return 0;
    return fact[n] * obr[k] % MOD * obr[n - k] % MOD;
}

long long get_bit_cnt(long long x)
{
    long long res = 0;
    while (x > 0) {
        res += x & 1;
        x >>= 1;
    }
    return res;
}

long long path_cnt[BIT_SZ][BIT_SZ];
long long numb_cnt[BIT_SZ];
long long ans[BIT_SZ];

void build_path_cnt()
{
    path_cnt[0][1] = 1;
    for (long long b = 1; b <= 60; b++) {
        path_cnt[b][1] = 1;
        for (long long len = 2; len <= min(b + 1, n); len++) {
            for (long long i = 1; i <= b; i++) {
                path_cnt[b][len] += path_cnt[b - i][len - 1] * get_C(b, i) % MOD;
                path_cnt[b][len] %= MOD;
            }
        }
    }
    for (long long b = 0; b <= 60; b++) {
        for (long long len = 1; len <= min(b + 1, n); len++) {
            ans[b] += get_C(n - 1, len - 1) * path_cnt[b][len] % MOD;
            ans[b] %= MOD;
        }
    }
}

void build_numb_cnt()
{
    vector<long long> vect;
    long long k_now = k;
    while (k_now > 0) {
        vect.push_back(k_now & 1);
        k_now >>= 1;
    }
    reverse(vect.begin(), vect.end());
    numb_cnt[get_bit_cnt(k)] = 1;
    for (long long b = 0; b <= 60; b++) {
        long long sum = 0;
        for (long long i = 0; i < vect.size(); i++) {
            if (vect[i] == 0)
                continue;
            sum++;
            if (sum - 1 > b)
                break;
            numb_cnt[b] += get_C(vect.size() - i - 1, b - sum + 1);
            numb_cnt[b] %= MOD;
        }
    }
}

long long action(long long x)
{
    return numb_cnt[x] * ans[x] % MOD;
}

signed main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    cin >> n >> m >> k;
    build_fact();
    build_path_cnt();
    build_numb_cnt();

    long long res = 0;
    for (long long i = 0; i <= 60; i++) {
        res += action(i);
        res %= MOD;
    }
    cout << res;
    return 0;
}
