#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <random>
#include <time.h>


using namespace std;


const int MEM = (int)1e8;


char ALLOC[MEM];
int pos = 0;

void* operator new(size_t sz) {
    void* res = ALLOC + pos;

    pos += sz;

    return res;
}

void operator delete(void *p) {};


int randint() {
    return (rand() << 16) + rand();
}


const int MAXN = (int)3e5;
const int INF = (int)1e6;


class Treap {
    struct Node {
        int x, npos, minnpos, sz, depth;

        Node *L = nullptr, *R = nullptr;

        Node(int x, int npos) : x(x), npos(npos), minnpos(npos), sz(1), depth(1) {};
    };

    inline int get_sz(Node *N) {
        if (!N) {
            return 0;
        }

        return N->sz;
    }

    inline int get_depth(Node *N) {
        if (!N) {
            return 0;
        }

        return N->depth;
    }

    inline int get_minpos(Node *N) {
        if (!N) {
            return INF;
        }

        return N->minnpos;
    }

    inline bool hpr(Node *L, Node *R) {
        int lsize = get_sz(L), rsize = get_sz(R);

        return randint() % (lsize + rsize) < lsize;
    }

    inline void update(Node *N) {
        if (!N) {
            return;
        }

        N->sz = get_sz(N->L) + get_sz(N->R) + 1;
        N->minnpos = min({ N->npos, get_minpos(N->L), get_minpos(N->R) });
        N->depth = max(get_depth(N->L), get_depth(N->R)) + 1;
    }

    Node* merge(Node *L, Node *R) {
        if (!L) {
            return R;
        }

        if (!R) {
            return L;
        }

        Node *T;

        if (hpr(L, R)) {
            L->R = merge(L->R, R);

            T = L;
        } else {
            R->L = merge(L, R->L);

            T = R;
        }

        update(T);

        return T;
    }

    void split(Node *T, int x, Node *&L, Node *&R) {
        if (!T) {
            L = R = nullptr;

            return;
        }

        int ls = get_sz(T->L);

        if (ls < x) {
            split(T->R, x - ls - 1, T->R, R);

            L = T;
        } else {
            split(T->L, x, L, T->L);

            R = T;
        }

        update(T);
    }

    Node *root = nullptr;

public:
    Treap() {};

    void insert(int x, int npos, int i) {
        Node *L = nullptr, *R = nullptr;

        split(root, i, L, R);

        root = merge(merge(L, new Node(x, npos)), R);
    }

    int get_front() {
        Node *N = root;

        while (N->L) {
            N = N->L;
        }

        return N->x;
    }

    void pop_front() {
        Node *L = nullptr, *R = nullptr;

        split(root, 1, L, R);

        root = R;
    }

    int get_inpos(int npos) {
        Node *N = root;

        int i = 0;

        while (get_sz(N) > 0) {
            if (get_minpos(N->R) > npos) {
                if (N->npos < npos) {
                    return i + get_sz(N->L) + 1;
                }

                N = N->L;
            } else {
                i += get_sz(N->L) + 1;

                N = N->R;
            }
        }

        return i;
    }

    int depth() {
        return get_depth(root);
    }
};


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    srand(time(0));

    int n, m;
    cin >> n >> m;

    vector<int> a(m);
    for (int i = 0; i < m; ++i) {
        cin >> a[i];

        --a[i];
    }

    vector<int> b(n);
    for (int i = 0; i < n; ++i) {
        cin >> b[i];

        --b[i];
    }

    vector<int> npos(n, INF);
    vector<int> next(m, INF);
    vector<int> last(n, -1);
    for (int i = 0; i < m; ++i) {
        if (last[a[i]] != -1) {
            next[last[a[i]]] = i;
        } else {
            npos[a[i]] = i;
        }

        last[a[i]] = i;
    }

    Treap tree;
    for (int i = 0; i < n; ++i) {
        tree.insert(b[i], npos[b[i]], i);
    }

    vector<int> act;

    for (int i = 0; i < m; ++i) {
        int cur = tree.get_front();

        while (cur != a[i]) {
            if (tree.depth() > 100) {
                return 1;
            }

            tree.pop_front();

            int k = tree.get_inpos(npos[cur]);

            tree.insert(cur, npos[cur], k);

            act.push_back(k + 1);

            cur = tree.get_front();
        }

        npos[cur] = next[i];

        tree.pop_front();

        int k = tree.get_inpos(npos[cur]);

        tree.insert(cur, npos[cur], k);

        act.push_back(k + 1);
    }

    cout << act.size() << '\n';
    for (int x : act) {
        cout << x << ' ';
    }

    return 0;
}