#include <iostream>
#include <vector>
#include <algorithm>
#include <string>


using namespace std;


const int MEM = (int)1e8;


char ALLOC[MEM];
int pos = 0;

void* operator new(size_t sz) {
    void* res = ALLOC + pos;

    pos += sz;

    return res;
}

void operator delete(void *p) {};


const int MAXN = (int)3e5;
const int INF = (int)1e6;
const int K = 500, HF = K / 2;


class SBR {
    vector<vector<pair<int, int>>> blocks = { {} };
    vector<int> szs = { 0 };
    vector<vector<int>> nposs = { { INF } };

    void split(int block) {
        cout << "DD";

        blocks.insert(blocks.begin() + block + 1, {});
        szs.insert(szs.begin() + block + 1, 0);
        nposs.insert(nposs.begin() + block + 1, { INF });

        vector<pair<int, int>> cur = blocks[block];
        blocks[block] = {};
        szs[block] = 0;
        nposs[block] = { INF };

        for (int i = 0; i < HF; ++i) {
            insert(cur[i].first, cur[i].second, i, block);
        }

        for (int i = HF; i < K; ++i) {
            insert(cur[i].first, cur[i].second, i - HF, block + 1);
        }
    }

    void insert(int x, int npos, int i, int block) {
        vector<pair<int, int>> &cb = blocks[block];

        cb.insert(cb.begin() + i, { x, npos });
        
        vector<int> &cnp = nposs[block];
        cnp.insert(lower_bound(cnp.begin(), cnp.end(), npos), npos);
        
        if (++szs[block] == K) {
            split(block);
        }
    }

    void erase(int i, int block) {
        vector<pair<int, int>> &cb = blocks[block];

        int cnpos = cb[i].second;

        cb.erase(cb.begin() + i);

        vector<int> &cnp = nposs[block];
        cnp.erase(lower_bound(cnp.begin(), cnp.end(), cnpos));

        if (--szs[block] == 0 && szs.size() > 1) {
            blocks.erase(blocks.begin() + block);
            szs.erase(szs.begin() + block);
            nposs.erase(nposs.begin() + block);
        }
    }

public:
    SBR() {};

    void insert(int x, int npos, int i) {
        int cur;
        for (cur = 0; i > szs[cur]; ++cur) {
            i -= szs[cur];
        }

        insert(x, npos, i, min(cur, (int)szs.size() - 1));
    }

    void erase(int i) {
        int cur;
        for (cur = 0; i >= szs[cur]; ++cur) {
            i -= szs[cur];
        }

        erase(i, cur);
    }

    int get_front() {
        return blocks[0][0].first;
    }

    void pop_front() {
        erase(0, 0);
    }

    int get_inpos(int npos) {
        int bs = szs.size();

        int cur;
        for (cur = bs - 1; cur >= 0 && nposs[cur][0] > npos; --cur);

        if (cur == -1) {
            return 0;
        }

        int i;
        for (i = szs[cur] - 1; i >= 0 && blocks[cur][i].second > npos; --i);

        int answ = 0;
        for (int c = 0; c < cur; ++c) {
            answ += szs[c];
        }

        return answ + i + 1;
    }
};


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    int n, m;
    cin >> n >> m;

    vector<int> a(m);
    for (int i = 0; i < m; ++i) {
        cin >> a[i];

        --a[i];
    }

    vector<int> b(n);
    for (int i = 0; i < n; ++i) {
        cin >> b[i];

        --b[i];
    }

    vector<int> npos(n, INF);
    vector<int> next(m, INF);
    vector<int> last(n, -1);
    for (int i = 0; i < m; ++i) {
        if (last[a[i]] != -1) {
            next[last[a[i]]] = i;
        } else {
            npos[a[i]] = i;
        }

        last[a[i]] = i;
    }

    SBR tree;
    for (int i = 0; i < n; ++i) {
        tree.insert(b[i], npos[b[i]], i);
    }

    vector<int> act;

    for (int i = 0; i < m; ++i) {
        int cur = tree.get_front();

        while (cur != a[i]) {
            tree.pop_front();

            int k = tree.get_inpos(npos[cur]);

            tree.insert(cur, npos[cur], k);

            act.push_back(k + 1);

            cur = tree.get_front();
        }

        npos[cur] = next[i];

        tree.pop_front();

        int k = tree.get_inpos(npos[cur]);

        tree.insert(cur, npos[cur], k);

        act.push_back(k + 1);
    }

    cout << act.size() << '\n';
    for (int x : act) {
        cout << x << ' ';
    }

    return 0;
}